From: Thomas Gleixner <t...@linutronix.de>

Switch to the CPU hotplug core state tracking and synchronization
mechanim. No functional change intended.

Signed-off-by: Thomas Gleixner <t...@linutronix.de>
Tested-by: Mark Rutland <mark.rutl...@arm.com>
Tested-by: Michael Kelley <mikel...@microsoft.com>
---
 arch/arm64/Kconfig           |    1 +
 arch/arm64/include/asm/smp.h |    2 +-
 arch/arm64/kernel/smp.c      |   14 +++++---------
 3 files changed, 7 insertions(+), 10 deletions(-)


--- a/arch/arm64/Kconfig
+++ b/arch/arm64/Kconfig
@@ -222,6 +222,7 @@ config ARM64
        select HAVE_KPROBES
        select HAVE_KRETPROBES
        select HAVE_GENERIC_VDSO
+       select HOTPLUG_CORE_SYNC_DEAD if HOTPLUG_CPU
        select IRQ_DOMAIN
        select IRQ_FORCED_THREADING
        select KASAN_VMALLOC if KASAN
--- a/arch/arm64/include/asm/smp.h
+++ b/arch/arm64/include/asm/smp.h
@@ -99,7 +99,7 @@ static inline void arch_send_wakeup_ipi_
 
 extern int __cpu_disable(void);
 
-extern void __cpu_die(unsigned int cpu);
+static inline void __cpu_die(unsigned int cpu) { }
 extern void __noreturn cpu_die(void);
 extern void __noreturn cpu_die_early(void);
 
--- a/arch/arm64/kernel/smp.c
+++ b/arch/arm64/kernel/smp.c
@@ -332,17 +332,13 @@ static int op_cpu_kill(unsigned int cpu)
 }
 
 /*
- * called on the thread which is asking for a CPU to be shutdown -
- * waits until shutdown has completed, or it is timed out.
+ * Called on the thread which is asking for a CPU to be shutdown after the
+ * shutdown completed.
  */
-void __cpu_die(unsigned int cpu)
+void arch_cpuhp_cleanup_dead_cpu(unsigned int cpu)
 {
        int err;
 
-       if (!cpu_wait_death(cpu, 5)) {
-               pr_crit("CPU%u: cpu didn't die\n", cpu);
-               return;
-       }
        pr_debug("CPU%u: shutdown\n", cpu);
 
        /*
@@ -369,8 +365,8 @@ void __noreturn cpu_die(void)
 
        local_daif_mask();
 
-       /* Tell __cpu_die() that this CPU is now safe to dispose of */
-       (void)cpu_report_death();
+       /* Tell cpuhp_bp_sync_dead() that this CPU is now safe to dispose of */
+       cpuhp_ap_report_dead();
 
        /*
         * Actually shutdown the CPU. This must never fail. The specific hotplug




Reply via email to